CacheFile class

Represent a cached file.

Constructors

CacheFile(dynamic id, String url, String localName)
CacheFile.empty()
CacheFile.fromMap(Map<String, dynamic> item)

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pair
localName String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
getter/setter pair

Methods

isEmpty() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited