FionaImageCache class

This class represents a cache of images.

Constructors

FionaImageCache({required CacheFileRepository repository, String? cacheFolder})

Properties

cacheFolder String?
specific cache folder name
getter/setter pair
defaultCacheFolder String
Default cache folder name
final
hashCode int
The hash code for this object.
no setterinherited
repository CacheFileRepository
Repository to manage the downloaded images
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cleanCache() Future<void>
cleanOrphanFiles() Future<void>
downloadImage(String url, String localPath) Future
getImagePath(String url) Future<String>
Returns the image by url Tries to get the image from the repository. If it is not there, then downloads and saves it.
imageUrlToFile(String imageUrl, String fullLocalName) Future<File?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(String url) Future<CacheFile>
Saves the image into the repository
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited