getImagePath method
Returns the image by url Tries to get the image from the repository. If it is not there, then downloads and saves it.
Implementation
Future<String> getImagePath(String url) async {
CacheFile cacheFile = await save(url);
return _getLocalPath(cacheFile);
}