FionaImageUrl class

Gets the image file from an url

Implemented types

Constructors

FionaImageUrl()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getImageBytes(dynamic url) Future
override
imageUrlToFile(String imageUrl, String fullLocalName) Future<File?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited