CacheFileRepository class abstract
Repository to manage cached files
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clean(
List< String> urls) → Future<void> - Cleans cached urls.
-
cleanAll(
) → Future< void> - Cleans all cached urls.
-
getByUrl(
String url) → Future< CacheFile> - Gets chage file by burl
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
CacheFile cacheFile) → Future< void> - Saves cache file
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited